CityJSON

Struct CityJSON 

pub struct CityJSON {
    pub thetype: String,
    pub version: String,
    pub transform: Transform,
    pub city_objects: HashMap<String, CityObject>,
    pub vertices: Vec<Vec<i64>>,
    pub metadata: Option<Metadata>,
    pub appearance: Option<Appearance>,
    pub geometry_templates: Option<GeometryTemplates>,
    pub extensions: Option<Value>,
    pub other: Value,
    /* private fields */
}

Fields

thetype: Stringversion: Stringtransform: Transformcity_objects: HashMap<String, CityObject>vertices: Vec<Vec<i64>>metadata: Option<Metadata>appearance: Option<Appearance>geometry_templates: Option<GeometryTemplates>extensions: Option<Value>other: Value

Implementations

Source

impl CityJSON

pub fn new() -> Self

Create a new CityJSON instance with default values.

pub fn from_str(s: &str) -> Result<Self, Error>

Create a new CityJSON instance from a string.

pub fn get_metadata(&self) -> Self

Get the “first line” (aka metadata or header) of a CityJSONSeq

pub fn get_cjfeature(&self, i: usize) -> Option<CityJSONFeature>

Getter for the features in a CityJSON dataset. Starts at 0, and return Option::None if the index is out of bounds.

pub fn add_transform_correction(&mut self, t: Transform)

Used when many CityJSONSeq are used, the “transform” can be modified (the new value is a “correction”).

pub fn add_cjfeature(&mut self, cjf: &mut CityJSONFeature)

pub fn remove_duplicate_vertices(&mut self)

pub fn update_geographicalextent(&mut self)

pub fn update_transform(&mut self)

pub fn number_of_city_objects(&self) -> usize

pub fn sort_cjfeatures(&mut self, ss: SortingStrategy)

When getting the CityJSONFeatures, this controls the order in which they are returned. By default they are returned in the order they were added.